documentFactory.SrbDocumentStream

|  | ## Cheshire3 Object Model: Class SrbDocumentStream

Module documentFactory :: Class SrbDocumentStream

## Class SrbDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
      RemoteDocumentStream --+
                             |
    BaseDocumentStream --+   |
                         |   |
    MultipleDocumentStream --+
                             |
                            SrbDocumentStream

Instance Methods

Inherited from `RemoteDocumentStream`: `parse_url` Inherited from `BaseDocumentStream`: `__init__`, `fetch_document`, `open_stream` Inherited from `MultipleDocumentStream` (private): `_fetchName`, `_fetchStream`, `_processFile`, `_processFiles`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`